@@ -317,7 +317,13 @@ def commits(pid):
         f.abort(404)
 
     page = f.request.args.get('page',1)
-    limit = f.request.args.get('limit',100)
+    limit = f.request.args.get('limit',50)
+    try:
+        page = int(page)
+        limit = int(limit)
+    except:
+        page = 1
+        limit = 50
 
     status_filter = f.request.args.get('status_filter','').strip()
     # Peewee queries are extra ugly - not sure why I chose it.
@@ -335,7 +341,7 @@ def commits(pid):
         print "\t", c.id
     
     return f.render_template('commits.html', project=project, 
-        statuses=statuses, commits=commits)
+        statuses=statuses, commits=commits, page=page, limit=limit)
 
 @app.route('/project/<pid>/roles')
 @requires_user()
